@@ -28,6 +28,7 @@
 #include <sys/wait.h>
 #include <sys/socket.h>  /* For have_ipv6() */
 #include <netdb.h>
+#include <time.h>
 
 #include <gconf/gconf-client.h>
 
@@ -313,6 +314,18 @@ gsm_shutdown_gconfd (void)
   g_free (command);
 }
 
+static gboolean
+is_later_than_date_of_doom (void)
+{
+  time_t t;
+  struct tm *tm;
+
+  t = time (NULL);
+  tm = localtime (&t);
+
+  return (tm->tm_year >= 105); /* We start on Jan 1 2006 */
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -324,10 +337,26 @@ main (int argc, char *argv[])
   gboolean a_t_support;
   GError *err;
   int status;
+  char *display_str;
+  char **versions;
   
   if (getenv ("GSM_VERBOSE_DEBUG"))
     gsm_set_verbose (TRUE);
-  
+
+  /* Help eradicate the critical warnings in unstable releases of GNOME */
+  versions = g_strsplit (VERSION, ".", 3);
+  if (versions && versions [0] && versions [1])
+    {
+      int major;
+      major = atoi (versions [1]);
+      if ((major % 2) != 0 && is_later_than_date_of_doom ())
+	{
+	  putenv ("G_DEBUG=fatal_criticals");
+	  g_log_set_always_fatal (G_LOG_LEVEL_CRITICAL);
+	}
+    }
+  g_strfreev (versions);
+      
   set_lang();
   set_gtk1_theme_rcfile ();
 
@@ -345,14 +374,8 @@ main (int argc, char *argv[])
   /* We need to do this as early as possible */
   gsm_set_display_properties ();
   
-  /* Make sure the splash screen has the SM_CLIENT_ID
-   * property set so smproxy doesn't try and session
-   * manage us.
-   * See http://bugzilla.gnome.org/show_bug.cgi?id=118063
-   */
-  gdk_set_sm_client_id ("gnome-session-dummy-id");
-
-  gnome_login_check ();
+  if (ORBit_proto_use ("IPv4") || ORBit_proto_use ("IPv6"))
+    gnome_login_check ();
 
   err = NULL;
   g_spawn_command_line_sync (GCONF_SANITY_CHECK, NULL, NULL, &status, &err);
@@ -372,6 +395,14 @@ main (int argc, char *argv[])
         }
     }
   
+  /* Read the config option early, so that we know if a11y is set or not */ 
+  gconf_client = gconf_client_get_default ();
+  gconf_client_add_dir (gconf_client, GSM_GCONF_CONFIG_PREFIX, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL); 
+  a_t_support = gconf_client_get_bool (gconf_client, ACCESSIBILITY_KEY, NULL);
+
+  if (a_t_support)
+    gsm_at_set_gtk_modules ();
+
   gnome_program_init("gnome-session", VERSION, LIBGNOMEUI_MODULE, argc, argv, 
 		  GNOME_PARAM_POPT_TABLE, options,
 		  NULL);
@@ -392,7 +423,9 @@ main (int argc, char *argv[])
 
   /* Make sure children see the right value for DISPLAY.  This is
      useful if --display was specified on the command line.  */
-  ep = g_strconcat ("DISPLAY=", gdk_get_display (), NULL);
+  display_str = gdk_get_display ();
+  ep = g_strconcat ("DISPLAY=", display_str, NULL);
+  g_free (display_str);
   putenv (ep);
 
   ignore (SIGPIPE);
@@ -400,10 +433,8 @@ main (int argc, char *argv[])
   /* Need DISPLAY set */
   gsm_keyring_daemon_start ();
   
-  /* Read in config options */  
-  gconf_client = gconf_client_get_default ();
+  /* Read the rest of config options */  
 
-  gconf_client_add_dir (gconf_client, GSM_GCONF_CONFIG_PREFIX, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
   splashing      = gconf_client_get_bool (gconf_client, SPLASH_SCREEN_KEY, NULL);
   autosave       = gconf_client_get_bool (gconf_client, AUTOSAVE_MODE_KEY, NULL);
   logout_prompt  = gconf_client_get_bool (gconf_client, LOGOUT_PROMPT_KEY, NULL);
@@ -477,8 +508,5 @@ main (int argc, char *argv[])
 
   clean_ice ();
 
-  /* If a logout command was set, the following will not return */
-  execute_logout ();
-  
   return 0;
 }
